@@ -544,8 +544,13 @@ class ExecutableAction(Action):
                                                  file_type=file_type,
                                                  title=title,
                                                  body=body)
+                    elif _resp.get("file") is not None:
+                        file_path = _resp.get("file")
+                        await pb.async_push_file_simple(file_path=file_path,use_transfer_sh=False,quiet=True,title=title, body=body)
+
                     else:
                         await pb.async_push_note(title=title, body=body)
+
                     del title, body
 
                 if type(response) == list:
